Crate wireless_mbus_link_layer

Crate wireless_mbus_link_layer 

Structs

ManufacturerId
WirelessFrame

Enums

FrameError

Functions

strip_format_a_crcs
Strip Format A CRCs from a wireless M-Bus frame.
trailing_frame_crc_start
Return the start offset of a trailing frame CRC when the final two bytes validate against every preceding byte.